Acknowledgements
================

**Contributors**: 

* John A. Marohn (JAM; Cornell University; `jam99@cornell.edu <mailto:jam99@cornell.edu>`__)

* Eric W. Moore (EWM; Cornell University)

* Sarah R. Nathan (SRN; Cornell University)

**Funding**:

The authors acknowledge salary support from the following funding sources:  

#. National Institutes of Health grants R01GM070012 and F33GM105241 -- EWM, JAM

#. The Army Research Office grants DMR W911NF-12-1-0221 and MURI W911NF-05-1-0403 -- JAM

#. National Science Foundation grant DMR-1006633 -- JAM

#. National Science Foundation Graduate Fellowship -- SRN

#. Cornell University -- JAM, SRN 

*Any opinions, findings, conclusions, or recommendations expressed in this code are those of the author(s) and do not necessarily reflect the views of Cornell University, the NSF, the NIH, or the ARO.*

